@@ -849,23 +849,23 @@ def test_list_edit():
     assert mock.call_count == 1
     mock.assert_called_with([1, 2, 3, 3])
 
-    list_edit.btn_minus.changed()
-    assert list_edit.value == [1, 2, 3]
-    assert list_edit.data == [1, 2, 3]
+    list_edit[1].btn_minus.changed()
+    assert list_edit.value == [1, 3, 3]
+    assert list_edit.data == [1, 3, 3]
     assert mock.call_count == 2
-    mock.assert_called_with([1, 2, 3])
+    mock.assert_called_with([1, 3, 3])
 
     list_edit.data[0] = 0
-    assert list_edit.value == [0, 2, 3]
-    assert list_edit.data == [0, 2, 3]
+    assert list_edit.value == [0, 3, 3]
+    assert list_edit.data == [0, 3, 3]
     assert mock.call_count == 3
-    mock.assert_called_with([0, 2, 3])
+    mock.assert_called_with([0, 3, 3])
 
     list_edit[0].value = 10
-    assert list_edit.value == [10, 2, 3]
-    assert list_edit.data == [10, 2, 3]
+    assert list_edit.value == [10, 3, 3]
+    assert list_edit.data == [10, 3, 3]
     assert mock.call_count == 4
-    mock.assert_called_with([10, 2, 3])
+    mock.assert_called_with([10, 3, 3])
 
     list_edit.data[:2] = [6, 5]  # type: ignore
     assert list_edit.value == [6, 5, 3]
@@ -912,10 +912,10 @@ def test_list_edit():
         pass
 
     assert type(f3.x) is widgets.ListEdit
-    assert type(f3.x[0]) is widgets.Slider
-    assert f3.x[0].min == -10
-    assert f3.x[0].max == 10
-    assert f3.x[0].step == 5
+    assert type(f3.x[0].value_widget) is widgets.Slider
+    assert f3.x[0].value_widget.min == -10
+    assert f3.x[0].value_widget.max == 10
+    assert f3.x[0].value_widget.step == 5
 
     @magicgui
     def f4(x: List[int] = ()):  # type: ignore
@@ -926,7 +926,7 @@ def test_list_edit():
     assert f4.x._args_type is int
     assert f4.x.value == []
     f4.x.btn_plus.changed()
-    assert type(f4.x[0]) is widgets.SpinBox
+    assert type(f4.x[0].value_widget) is widgets.SpinBox
     assert f4.x.value == [0]
 
     @magicgui
@@ -936,7 +936,7 @@ def test_list_edit():
     assert type(f5.x) is widgets.ListEdit
     assert f5.x.annotation == List[int]
     f5.x.btn_plus.changed()
-    assert f5.x[0].max == 3
+    assert f5.x[0].value_widget.max == 3
 
 
 def test_tuple_edit():
@@ -1059,6 +1059,56 @@ def test_literal():
     assert sel.choices == get_args(Lit)
 
 
+def test_separator_singleton():
+    from magicgui.types import Separator, _Separator
+
+    sep1 = Separator
+    sep2 = _Separator()
+    assert sep1 is sep2
+
+
+def test_separator(backend: str):
+    from magicgui.types import Separator
+
+    use_app(backend)
+
+    sep = [[Separator] * (i + 1) for i in range(4)]
+    a = [1, 2, *sep[0], 4, *sep[1], 6, 7, *sep[2], 9, *sep[3], 11, 12, *sep[0], 14, *sep[0]]
+    b = [1, 2, *sep[0], 4, *sep[1], 6, 7, *sep[2], 9, *sep[3], 6, 7, *sep[0], 9, *sep[0]]
+    b2 = [1, 2, *sep[0], 4, *sep[1], 6, 7, *sep[2], 9, *sep[3], *sep[0], *sep[0]]
+
+    combo_a = widgets.ComboBox(choices=a, value=a[0])
+    combo_b = widgets.ComboBox(choices=b, value=b[0])
+
+    assert len(combo_a) == len(combo_a.choices)
+    assert len(combo_b) == len(combo_b.choices)
+
+    if backend == "qt":
+        def get_all_itemdata(combo_box):
+            return [combo_box.itemData(index) for index in range(combo_box.count())]
+
+        # Count returns the number of all items including separator items
+        assert combo_a.native.count() == 21
+        assert combo_b.native.count() == 18
+
+        # Separator singletons themselves are used as separator item data
+        assert get_all_itemdata(combo_a.native) == a
+        assert get_all_itemdata(combo_b.native) == b2
+
+        # Choices only returns unique, non-separator items
+        assert combo_a.choices == (1, 2, 4, 6, 7, 9, 11, 12, 14)
+        assert combo_b.choices == (1, 2, 4, 6, 7, 9)
+
+    if backend == "ipynb":
+        # Separator singletons themselves are used as separator item data
+        assert combo_a.options['choices'] == a
+        assert combo_b.options['choices'] == b  # items are not unique
+
+        # Choices only returns duplicated, non-separator items
+        assert combo_a.choices == (1, 2, 4, 6, 7, 9, 11, 12, 14)
+        assert combo_b.choices == (1, 2, 4, 6, 7, 9, 6, 7, 9)
+
+
 def test_float_slider_readout():
     sld = widgets.FloatSlider(value=4, min=0.5, max=10.5)
     assert sld.value == 4
